#ifndef AlbumInformationManager_h
#define AlbumInformationManager_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TrackInformation.h"

#include <QBasicTimer>
#include <QImage>
#include <QObject>
#include <QList>
#include <QNetworkAccessManager>
#include <QPair>
#include <QTimerEvent>
#include <QUrl>

class AlbumInformationManager: public QObject, private Base::Counter<AlbumInformationManager>
{

    Q_OBJECT

    public:

    //* constructor
    explicit AlbumInformationManager( QObject* = nullptr );

    using ReleaseDatePair = QPair<TrackInformation, int>;
    using ReleaseDateList = QList<ReleaseDatePair>;

    Q_SIGNALS:

    //* emitted when a list of release dates are found
    void releaseDatesFound( AlbumInformationManager::ReleaseDateList );

    public Q_SLOTS:

    //* request album
    void get( const TrackInformation& );

    protected:

    //* timer event
    void timerEvent( QTimerEvent* ) override;

    private Q_SLOTS:

    //* download page
    void _download( const TrackInformation&, const QUrl& );

    //* save release date
    void _save( const TrackInformation&, int );

    private:

    //* delayed release date found
    void _delayedReleaseDateFound( const TrackInformation&, int );

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

    //* empty image
    QImage empty_;

    //* timer
    QBasicTimer timer_;

    //* pending items
    ReleaseDateList pendingItems_;

};

#endif
