#ifndef AlbumInformationManager_p_h
#define AlbumInformationManager_p_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "NetworkJob.h"
#include "TimeStamp.h"
#include "TrackInformation.h"

#include <QObject>
#include <QNetworkReply>
#include <QUrl>

#include <memory>

namespace Private
{

    //* used to get cover url from last.fm
    class AlbumInformationLocationJob: public NetworkJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AlbumInformationLocationJob( const TrackInformation&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when release date is found
        void releaseDateFound( TrackInformation, int );

        //* emitted when a information is found
        void informationFound( TrackInformation, QUrl );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* destination file
        TrackInformation trackInformation_;

    };

    //* used to downolad covers from given location
    class AlbumInformationJob: public NetworkJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AlbumInformationJob( const TrackInformation&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when release date is found
        void releaseDateFound( TrackInformation, int );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* track information
        TrackInformation trackInformation_;

    };
}

#endif
