#ifndef AudioDeviceInterface_h
#define AudioDeviceInterface_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TrackInformation.h"

#include <QWidget>

#include <memory>

//* read tracks from audio cd
class AudioDeviceInterface: public QObject, private Base::Counter<AudioDeviceInterface>
{

    Q_OBJECT

    public:

    //* construcor
    explicit AudioDeviceInterface( QObject* = nullptr );

    //* destructor
    ~AudioDeviceInterface() override;

    //*@name modifiers
    //@{

    void setCddbEnabled( bool value )
    { cddbEnabled_ = value; }

    //@}

    Q_SIGNALS:

    //* device invalid
    void invalidDevice( QString );

    //* list of collection items in device
    void tracksFound( TrackInformation::List );

    //* tracks updated
    void trackUpdated( TrackInformation, TrackInformation );

    public Q_SLOTS:

    //* initialize server
    void initializeServer();

    //* try read device
    /** do nothing if already locked */
    void tryReadDevice( const QString& );

    //* read device
    void readDevice( const QString& );

    //* init cdio
    bool tryInitCdio();

    //* save elapsed time
    void saveElapsedTime( quint32 );

    private Q_SLOTS:

    //* new connection
    void _newConnection();

    //* update tracks
    void _updateTracks( const TrackInformation::List& );

    private:

    //* read disc
    bool _readDisc();

    //* init cdio
    bool _initCdio();

    //* reset stored structures
    void _reset();

    //* true if cddb is enabled
    bool cddbEnabled_ = true;

    //* private pointer
    class Private;
    std::unique_ptr<Private> d;

    friend class AudioDeviceSocket;

};

#endif
