#ifndef AudioDeviceWidget_h
#define AudioDeviceWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "AudioDeviceModel.h"

#include <QAction>
#include <QLabel>
#include <QWidget>

class BrowsedLineEditor;
class TreeView;

class AudioDeviceWidget: public QWidget, private Base::Counter<AudioDeviceWidget>
{

    Q_OBJECT

    public:

    //* constructor
    explicit AudioDeviceWidget( QWidget* = nullptr );


    //*@name accessors
    //@{

    //* list
    TreeView& list() const
    { return *list_; }

    //* model
    const AudioDeviceModel& model() const
    { return model_; }

    //@}

    //*@name modifiers
    //@{

    //* model
    AudioDeviceModel& model()
    { return model_; }

    //* try update device
    void tryReadDevice();

    //@}

    Q_SIGNALS:

    //* request device update
    void requestTryReadDevice( QString );

    //* request device update
    void requestReadDevice( QString );

    //* add items to playlist
    void requestAddToPlaylist( const TrackInformation::List& );

    //* replace playlist
    void requestReplacePlaylist( const TrackInformation::List& );

    public Q_SLOTS:

    //* show notification widget
    void showNotificationWidget();

    //* add tracks
    void addTracks( const TrackInformation::List& );

    //* update track
    void updateTrack( const TrackInformation& oldTrack, const TrackInformation& newTrack );

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    //* update actions
    void _updateActions();

    //* save device
    void _saveDevice();

    //* add to playlist
    void _addItemToPlaylist( const QModelIndex& );

    //* add to playlist
    void _addSelectionToPlaylist();

    //* replace playlist
    void _replacePlaylist();

    private:

    //* actions
    void _installActions();

    //* device editor
    BrowsedLineEditor* deviceEditor_ = nullptr;

    //* treeview
    TreeView* list_ = nullptr;

    //* notification widget
    QLabel* notificationWidget_ = nullptr;

    //* model
    AudioDeviceModel model_;

    //*@name actions
    //@{

    //* add to playlist
    QAction* addToPlaylistAction_ = nullptr;

    //* replace playlist
    QAction* replacePlaylistAction_ = nullptr;

    //@}

};

#endif
