#ifndef AudioStreamInterface_h
#define AudioStreamInterface_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "AudioStreamItem.h"

#include <QNetworkAccessManager>

class ScrollBarMonitor;
class AudioStreamFindWidget;
class AudioStreamView;
class AudioStreamItemToolTipWidget;

//* used to convert audio stream urls to valid name
class AudioStreamConverter: public QObject, private Base::Counter<AudioStreamConverter>
{

    Q_OBJECT

    public:

    //* constructor
    explicit AudioStreamConverter( QObject*, const AudioStreamItem::List&, int );

    //*@name modifiers
    //@{

    //* run
    void run();

    //@}

    Q_SIGNALS:

    //* emitted when finished
    void finished( const AudioStreamItem::List&, int );

    //* emitted when finished
    void finished();

    private Q_SLOTS:

    //* update audio stream
    void _updateAudioStream( const AudioStreamItem&, const QString& );

    private:

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

    //* initial audio stream list
    AudioStreamItem::List items_;

    //* insertion row
    int row_ = 0;

};

class AudioStreamInterface: public QObject, private Base::Counter<AudioStreamInterface>
{

    Q_OBJECT

    public:

    //* constructor
    explicit AudioStreamInterface( QObject* = nullptr );

    //* hard coded provider strings
    static const QString iceCastUrl;
    static const QString shoutCastHost;
    static const QString shoutCastApiKey;

    Q_SIGNALS:

    //* emitted when a cover is found
    void childrenFound( AudioStreamItem, AudioStreamItem::List );

    public Q_SLOTS:

    //* find children of a given item
    void findChildren( const AudioStreamItem& );

    private:

    //* icecast children
    void _findIceCastChildren( const AudioStreamItem& );

    //* shoutcast children
    void _findShoutCastChildren( const AudioStreamItem& );

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

};

#endif
