#ifndef AudioStreamInterface_p_h
#define AudioStreamInterface_p_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "NetworkJob.h"
#include "AudioStreamItem.h"

#include <QObject>
#include <QNetworkReply>
#include <QUrl>

#include <memory>

namespace Private
{

    //* get audioStream genre or channels from parent audioStream
    class AudioStreamJob: public NetworkJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AudioStreamJob( const AudioStreamItem&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when a cover is found
        void childrenFound( AudioStreamItem, AudioStreamItem::List );

        //* audio stream is updated
        void audioStreamUpdated( AudioStreamItem, QString );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* icecast
        void _processIceCastReply();

        //* shoutcast
        void _processShoutCastReply();

        //* shoutcast
        void _processShoutCastChannelReply();

        //* parse genres
        static QSet<QString> _parseGenres( const QString& );

        //* uncompress (gzip) input
        static QByteArray _tryUncompress( QIODevice& );

        //* AudioStream item
        AudioStreamItem parentItem_;

    };

}

#endif
