#ifndef AudioStreamItemToolTipWidget_h
#define AudioStreamItemToolTipWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseToolTipWidget.h"
#include "AudioStreamItem.h"

#include <QIcon>
#include <QFrame>
#include <QLabel>

class GridLayoutItem;

class AudioStreamItemToolTipWidget: public BaseToolTipWidget
{

    Q_OBJECT

    public:

    //* constructor
    explicit AudioStreamItemToolTipWidget( QWidget* = nullptr );

    //* set audioStream
    void setAudioStreamItem( const AudioStreamItem&, const QIcon& = QIcon(), int entries = 0 );

    protected:

    //* reload
    void _reload()
    { setAudioStreamItem( audioStreamItem_, icon_, entries_ ); }

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    private:

    //* pixmap size
    void _setPixmapSize( int value )
    {
        if( pixmapSize_ == value ) return;
        pixmapSize_ = value;
        _reload();
    }

    //* pixmap size
    int pixmapSize_ = 0;

    //* audioStream
    AudioStreamItem audioStreamItem_;

    //* icon
    QIcon icon_;

    //* entries
    int entries_ = 0;

    //* icon label
    QLabel* iconLabel_ = nullptr;

    //*@name items
    //@{
    GridLayoutItem* providerItem_ = nullptr;
    GridLayoutItem* parentGenreItem_ = nullptr;
    GridLayoutItem* genreItem_ = nullptr;
    GridLayoutItem* channelItem_ = nullptr;
    GridLayoutItem* aliasItem_ = nullptr;
    GridLayoutItem* urlItem_ = nullptr;
    GridLayoutItem* entriesItem_ = nullptr;
    //@}

};

#endif
