#ifndef AudioStreamModel_h
#define AudioStreamModel_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "AudioStreamItem.h"
#include "CoverCache.h"
#include "TreeModel.h"

//* audioStream model
class AudioStreamModel: public TreeModel<AudioStreamItem>, private Base::Counter<AudioStreamModel>
{

    Q_OBJECT

    public:

    //* constructor
    explicit AudioStreamModel( QObject* = nullptr );

    //* colums
    enum ColumnType
    {
        Name,
        nColumns
    };

    //*@name accessors
    //@{

    //* flags
    Qt::ItemFlags flags( const QModelIndex& ) const override;

    //* mime type
    QStringList mimeTypes() const override;

    //* mime data
    QMimeData* mimeData( const QModelIndexList& ) const override;

    //* data
    QVariant data( const QModelIndex&, int ) const override;

    //* header
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* columns
    int columnCount(const QModelIndex& = QModelIndex()) const override
    { return nColumns; }

    //* children
    /** needs overwrite because of lazy filling of the list */
    bool hasChildren( const QModelIndex& ) const override;

    //* get icon for audioStream item
    QIcon icon( const AudioStreamItem& ) const;

    //@}

    //*@name modifiers
    //@{

    // modify data
    bool setData( const QModelIndex&, const QVariant&, int = Qt::EditRole ) override;

    //* drop mine data
    bool dropMimeData( const QMimeData*, Qt::DropAction, int, int, const QModelIndex& ) override;

    //@}

    Q_SIGNALS:

    //* request add to favorites
    void requestAddToFavorites();

    //* item renamed
    void audioStreamRenamed( const AudioStreamItem&, const AudioStreamItem& );

};


#endif
