/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AudioStreamProxyModel.h"
#include "AudioStreamModel.h"

#include "Debug.h"

//__________________________________________________________
AudioStreamProxyModel::AudioStreamProxyModel( QObject* parent ):
    QSortFilterProxyModel( parent ),
    Counter( "AudioStreamProxyModel" )
{ Debug::Throw( "AudioStreamProxyModel::AudioStreamProxyModel.\n" ); }

//__________________________________________________________________
bool AudioStreamProxyModel::hasChildren( const QModelIndex& parent ) const
{ return static_cast<const AudioStreamModel*>( sourceModel() )->hasChildren( mapToSource( parent ) ); }

//__________________________________________________________________
bool AudioStreamProxyModel::filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const
{
    // check filter regexp
    if( filterRegExp().isEmpty() ) return true;

    // get item from source model
    auto audioStreamModel( static_cast<const AudioStreamModel*>( sourceModel() ) );
    const auto index( audioStreamModel->index( sourceRow, 0, sourceParent ) );
    const auto item( audioStreamModel->get( index ) );

    switch( item.type() )
    {
        default:
        case AudioStreamItem::Type::Provider: return true;
        case AudioStreamItem::Type::Genre:
        {

            // get children
            const auto children( audioStreamModel->children( index ) );
            return std::any_of( children.begin(), children.end(), [this]( const AudioStreamItem& item )
            { return item.genre().contains( filterRegExp() ) || item.channel().contains( filterRegExp() ); } );

        }

        case AudioStreamItem::Type::Channel:
        return
            item.genre().contains( filterRegExp() ) ||
            item.channel().contains( filterRegExp() );
    }

}
