/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseLyricsProvider.h"
#include "BaseLyricsProvider_p.h"

namespace Private
{

    //______________________________________________________________________
    LyricsRequest::LyricsRequest( const TrackInformation& trackInformation, QNetworkReply* networkReply ):
        Counter( "Private::LyricsRequest" ),
        trackInformation_( trackInformation ),
        networkReply_( networkReply )
    {
        Debug::Throw( "Private::LyricsRequest::LyricsRequest.\n" );

        // connect
        connect( networkReply_.get(), SIGNAL(finished()), this, SLOT(_finished()) );
    }

    //______________________________________________________________________
    LyricsRequest::~LyricsRequest() = default;

    //_______________________________________________________________________________
    void LyricsRequest::_finished()
    {
        Debug::Throw( "Private::LyricsRequest::_finished.\n" );
        if( networkReply_ && networkReply_->error() == QNetworkReply::NoError )
        {

            emit lyricsFound( trackInformation_, networkReply_->readAll() );

        } else emit lyricsNotFound( trackInformation_ );
        emit finished();

    }

}

//______________________________________________________________________
BaseLyricsProvider::BaseLyricsProvider( QObject* parent ):
    QObject( parent ),
    Counter( "BaseLyricsProvider" )
{}

//______________________________________________________________________
void BaseLyricsProvider::get( const TrackInformation& )
{}


//______________________________________________________________________
QString BaseLyricsProvider::_extract( const QString& data, const QString& begin, const QString& end )
{
    QString out;

    for( int beginPosition = 0; (beginPosition = data.indexOf( begin, beginPosition ) ) >= 0; )
    {

        beginPosition += begin.length();
        auto endPosition = data.indexOf( end, beginPosition );
        if( endPosition < 0 ) break;
        else {

            if( !out.isEmpty() ) out += "\n";
            out += data.mid( beginPosition, endPosition-beginPosition );
            beginPosition = endPosition + end.length();

        }
    }

    return out;

}

//______________________________________________________________________
QString BaseLyricsProvider::_exclude( const QString& data, const QString& begin, const QString& end )
{
    auto beginPosition = data.indexOf( begin );
    if( beginPosition < 0 ) return data;

    auto endPosition = data.indexOf( end, beginPosition );
    if( endPosition < 0 ) return data;
    endPosition += end.length();

    return data.left( beginPosition ) + data.mid( endPosition );

}
