#ifndef BaseLyricsProvider_h
#define BaseLyricsProvider_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Functors.h"
#include "LyricsInformation.h"
#include "TrackInformation.h"

#include <QNetworkAccessManager>
#include <QObject>
#include <QList>

class BaseLyricsProvider: public QObject, private Base::Counter<BaseLyricsProvider>
{

    Q_OBJECT

    public:

    using List = QList<BaseLyricsProvider*>;

    //* constructor
    explicit BaseLyricsProvider( QObject* = nullptr );

    //*@name accessors
    //@{

    //* name
    const QString& name() const
    { return name_; }

    //@}

    //*@name modifiers
    //@{

    //* name
    void setName( const QString& value )
    { name_ = value; }

    //* set network access manager
    void setNetworkAccessManager( QNetworkAccessManager* value )
    { networkAccessManager_ = value; }

    //@}

    using SameNameFTor = Base::Functor::UnaryEqual<BaseLyricsProvider, const QString&, &BaseLyricsProvider::name>;

    Q_SIGNALS:

    //* lyrics found
    void lyricsFound( TrackInformation, LyricsInformation );

    //* lyrics not found
    void lyricsNotFound( TrackInformation );

    public Q_SLOTS:

    //* get lyrics for given track
    virtual void get( const TrackInformation& );

    protected:

    //* network access manager
    bool _hasNetworkAccessManager() const
    { return networkAccessManager_; }

    //* network access manager
    QNetworkAccessManager& _networkAccessManager() const
    { return *networkAccessManager_; }

    //* extract lyrics from data between provided tag
    static QString _extract( const QString&, const QString& begin, const QString& end );

    //* exclude lyrics from data between provided tag
    static QString _exclude( const QString&, const QString& begin, const QString& end );

    private:

    //* provider name
    QString name_;

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

};

#endif
