#ifndef BaseLyricsProvider_p_h
#define BaseLyricsProvider_p_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TrackInformation.h"
#include "ObjectDeleter.h"

#include <QNetworkReply>
#include <QRegExp>

#include <memory>

namespace Private
{

    class LyricsRequest: public QObject, private Base::Counter<LyricsRequest>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit LyricsRequest( const TrackInformation&, QNetworkReply* );

        //* destructor
        ~LyricsRequest() override;

        Q_SIGNALS:

        //* finished
        void finished();

        //* emitted when answer is retrieved
        void lyricsFound( TrackInformation, QByteArray );

        //* emitted in case of failure
        void lyricsNotFound( TrackInformation );

        private Q_SLOTS:

        //* finished
        void _finished();

        private:

        //* track information
        TrackInformation trackInformation_;

        //* network reply
        std::unique_ptr<QNetworkReply, Base::ObjectDeleter> networkReply_;

    };

}

#endif
