#ifndef CacheInformationItem_h
#define CacheInformationItem_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"

#include <QRegExp>

class CacheInformationItem: private Base::Counter<CacheInformationItem>
{

    public:

    using List = QList<CacheInformationItem>;

    enum class Type
    {
        Unknown,
        AlbumArt,
        Lyrics,
        Cddb,
        AudioStreams
    };

    //* default constructor
    explicit CacheInformationItem():
        Counter( "CacheInformationItem" )
        {}

    //* constructor
    explicit CacheInformationItem( Type type, const QString& name, const File& location ):
        Counter( "CacheInformationItem" ),
        type_( type ),
        name_( name ),
        location_( location )
        {}

    //*@name accessors
    //@{

    const QString& name() const
    { return name_; }

    const File& location() const
    { return location_; }

    int itemCount() const
    { return itemCount_; }

    qint64 size() const
    { return size_; }

    //@}

    //*@name modifiers
    //@{

    //* type
    void setType( Type value )
    { type_ = value; }

    //* name
    void setName( const QString& value )
    { name_ = value; }

    //* location
    void setLocation( const File& value )
    { location_ = value; }

    //* update cache information
    void update();

    //* clear cache
    void clear();

    //@}

    private:

    //* get regular expression for file selection, based on type
    QRegExp _fileRegExp() const;

    Type type_ = Type::Unknown;

    //* cache name
    QString name_;

    //* location
    File location_;

    //* item count
    int itemCount_ = 0;

    //* size
    qint64 size_ = 0;

    friend bool operator == ( const CacheInformationItem& lhs, const CacheInformationItem& rhs )
    { return lhs.type_ == rhs.type_; }

};

#endif
