/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CacheInformationModel.h"

//_______________________________________________________________________________________
CacheInformationModel::CacheInformationModel( QObject* parent ):
    ListModel( parent ),
    Counter( "CacheInformationModel" )
{}

//_______________________________________________________________________________________
Qt::ItemFlags CacheInformationModel::flags( const QModelIndex& index ) const
{ return index.isValid() ? Qt::ItemIsEnabled | Qt::ItemIsSelectable : Qt::NoItemFlags; }

//_______________________________________________________________________________________
QVariant CacheInformationModel::data( const QModelIndex& index, int role ) const
{

    // check index
    if( !contains( index ) ) return QVariant();

    const auto& item( get(index) );

    switch( role )
    {
        case Qt::DisplayRole:
        {
            switch( index.column() )
            {
                case Name: return item.name();
                case Location: return item.location().get();
                case ItemCount: return item.itemCount();
                case Size: return File::sizeString( item.size() );
                default: return QVariant();
            }
        }
    }
    return QVariant();

}


//__________________________________________________________________
QVariant CacheInformationModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    switch( role )
    {

        case Qt::DisplayRole:
        return columnTitles_[section];

        default: break;

    }

    // return empty
    return QVariant();

}

//__________________________________________________________________
void CacheInformationModel::update()
{
    emit layoutAboutToBeChanged();
    for( auto&& item:_get() )
    { item.update(); }
    emit layoutChanged();
}
