/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CollectionItemToolTipWidget.h"

#include "CustomPixmap.h"
#include "GridLayoutItem.h"

//_______________________________________________________
void CollectionItemToolTipWidget::setCollectionItem( const CollectionItem& item, const QIcon& icon )
{
    Debug::Throw( "CollectionItemToolTipWidget::setRecord.\n" );

    // local storage
    _setIcon( icon );
    item_ = item;

    // update icon
    if( !icon.isNull() )
    {

        // get pixmap
        _iconLabel().setPixmap( icon.pixmap( QSize( _pixmapSize(), _pixmapSize() ) ) );
        _iconLabel().show();

    } else _iconLabel().hide();

    // artist
    _artistItem().setText( item.artist().isEmpty() ? TrackInformation::UnknownArtist:item.artist() );

    // album
    if( item.type() != CollectionItem::Type::Artist )
    {

        _albumItem().setText( item.album().isEmpty() ? TrackInformation::UnknownAlbum:item.album() );

    } else _albumItem().hide();

    // title
    if( item.type() == CollectionItem::Type::Track )
    {

        _titleItem().setText( item.titleOrFile() );

    } else _titleItem().hide();

    // year
    if( item.year() > 0 && item.type() != CollectionItem::Type::Artist )
    {

        _yearItem().setText( QString::number( item.year() ) );

    } else _yearItem().hide();

    // track
    if( item.type() == CollectionItem::Type::Album && item.trackCount() > 0 ) {

        _trackItem().setKey( tr( "Tracks:" ) );
        _trackItem().setText( QString::number( item.trackCount() ) );

    } else if( item.type() == CollectionItem::Type::Artist && item.albumCount() > 0 ) {

        _trackItem().setKey( tr( "Albums:" ) );
        _trackItem().setText( QString::number( item.albumCount() ) );

    } else _trackItem().hide();

    // track
    if( item.disc() > 0 && item.type() == CollectionItem::Type::Track  )
    {

        _discItem().setText( QString::number( item.disc() ) );

    } else _discItem().hide();

    // duration
    if( item.duration() > 0 )
    {

        _durationItem().setText( item.durationString( item.type() == CollectionItem::Type::Album ) );

    } else _durationItem().hide();

    adjustSize();

}

//_____________________________________________
bool CollectionItemToolTipWidget::_updateCover( const CollectionItem& item, const QImage& image )
{

    if( isVisible() &&
        item_.type() == item.type() &&
        !image.isNull() &&
        (( item_.type() == CollectionItem::Type::Artist && item_.artist() == item.artist() ) ||
        ( item_.artist() == item.artist() && item_.album() == item.album() ) ) )
    {

        _setIcon( QIcon( QPixmap::fromImage( image ) ) );
        _reload();
        return true;

    } else return false;

}
