#ifndef CoverManager_p_h
#define CoverManager_p_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CollectionItem.h"
#include "Counter.h"
#include "File.h"
#include "NetworkJob.h"

#include <QObject>
#include <QNetworkReply>
#include <QUrl>

#include <memory>

namespace Private
{

    //* used to get cover url from last.fm
    class CoverLocationJob: public NetworkJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit CoverLocationJob( const CollectionItem&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when a cover is found
        void coverFound( CollectionItem, QUrl );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* collection item
        CollectionItem collectionItem_;

    };

    //* used to downolad covers from given location
    class CoverDownloadJob: public NetworkJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit CoverDownloadJob( const CollectionItem&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when a cover is found
        void coverFound( CollectionItem, QImage );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* collection item
        CollectionItem collectionItem_;

    };
}

#endif
