#ifndef CurrentTrackInformationWidget_h
#define CurrentTrackInformationWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CoverManager.h"
#include "Counter.h"
#include "TrackInformation.h"

#include <QIcon>
#include <QImage>
#include <QLabel>
#include <QPaintEvent>
#include <QPixmap>
#include <QWidget>


class ElidedLabel;

class CurrentTrackInformationWidget: public QWidget, private Base::Counter<CurrentTrackInformationWidget>
{

    Q_OBJECT;

    public:

    //* constructor
    explicit CurrentTrackInformationWidget( QWidget* = nullptr );

    //*@name modifiers
    //@{

    //* clear
    void clear();

    //* set track information
    void setTrackInformation( const TrackInformation&, const QIcon& = QIcon() );

    //@}

    public Q_SLOTS:

    //* update icon
    bool updateCover( const CoverManager::CoverList& );

    protected:

    //* paint
    void paintEvent( QPaintEvent* ) override;

    //* resize
    void resizeEvent( QResizeEvent* ) override
    { _updateBackgroundImage(); }

    //* context menu
    void contextMenuEvent( QContextMenuEvent* ) override;


    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    //* display cover
    void _displayCover();

    private:

    //* actions
    void _installActions();

    //* update default pixmap
    void _updateDefaultPixmap();

    //* update icon
    void _updateIcon();

    //* background
    void _updateBackgroundImage();

    //* pixmap size
    int pixmapSize_ = 0;

    //* current track information
    TrackInformation trackInformation_;

    //* local icon copy
    QIcon icon_;

    //* default pixmap
    QPixmap defaultPixmap_;

    //* current pixmap
    QPixmap currentPixmap_;

    //* background image
    QImage backgroundImage_;

    //* icon label
    QLabel* iconLabel_ = nullptr;

    //* artist
    ElidedLabel* artistLabel_ = nullptr;

    //* album
    ElidedLabel* albumLabel_ = nullptr;

    //* track
    ElidedLabel* trackLabel_ = nullptr;

    //*@name actions
    //@{

    //* display cover
    QAction* displayCoverAction_ = nullptr;

    //@}

};

#endif
