#ifndef DeleteTracksDialog_h
#define DeleteTracksDialog_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "QuestionDialog.h"
#include "CollectionItem.h"
#include "ListModel.h"

class DeleteTracksDialog: public QuestionDialog
{

    Q_OBJECT

    public:

    //* constructor
    explicit DeleteTracksDialog( QWidget* = nullptr );

    //*@name accessors
    //@{

    //* true if all requests have been completed
    bool requestsCompleted() const;

    //@}

    //*@name modifiers
    //@{

    //* reset
    void reset();

    //* add tracks
    void addItems( const CollectionItem::List& );

    //* set tracks
    void setItems( const CollectionItem::List& items )
    {
        reset();
        addItems( items );
    }

    //* delete
    void deleteTracks();

    //@}

    private:

    class SimpleModel: public ListModel<CollectionItem>, private Base::Counter<SimpleModel>
    {

        public:

        //* constructor
        explicit SimpleModel( QObject* = nullptr );

        //*@name accessors
        //@{

        //* flags
        Qt::ItemFlags flags( const QModelIndex& index ) const override
        { return index.isValid() ? Qt::ItemIsEnabled:Qt::NoItemFlags; }

        //* return data
        QVariant data( const QModelIndex&, int ) const override;

        //* header data
        QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole) const override
        { return QVariant(); }

        //* number of columns for a given index
        int columnCount( const QModelIndex& = QModelIndex() ) const override
        { return 1; }

    };

    //* update buttons
    void _updateButtons();

    //* update text
    void _updateText();

    //* list of collection items
    CollectionItem::List items_;

    //* model
    SimpleModel model_;

};

#endif
