/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LyricsInformation.h"

#include "XmlDef.h"

//____________________________________________________________
LyricsInformation::LyricsInformation( const QDomElement& element ):
    Counter( "LyricsInformation" )
{
    Debug::Throw( "LyricsInformation::LyricsInformation.\n" );

    // parse attributes
    const auto attributes( element.attributes() );
    for( int i=0; i<attributes.count(); i++ )
    {
        const auto attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        else if( attribute.name() == Xml::Artist ) artist_ = attribute.value();
        else if( attribute.name() == Xml::Title ) title_ = attribute.value();
        else if( attribute.name() == Xml::Provider ) provider_ = attribute.value();
        else if( attribute.name() == Xml::Url ) url_ = QUrl( attribute.value() );
    }

    // parse children
    for( auto&& node = element.firstChild(); !node.isNull(); node = node.nextSibling() )
    {
        auto element = node.toElement();
        if( element.isNull() ) continue;
        else if( element.tagName() == Xml::Content ) lyrics_ = element.text();
    }

}

//____________________________________________________________
QDomElement LyricsInformation::domElement( QDomDocument& document ) const
{
    Debug::Throw( "LyricsInformation::domElement.\n" );
    auto out( document.createElement( Xml::Lyrics ) );
    if( !artist_.isEmpty() ) out.setAttribute( Xml::Artist, artist_ );
    if( !title_.isEmpty() ) out.setAttribute( Xml::Title, title_ );
    if( !provider_.isEmpty() ) out.setAttribute( Xml::Provider, provider_ );
    if( url_.isValid() ) out.setAttribute( Xml::Url, url_.toString() );
    if( !lyrics_.isEmpty() )
    {
        out.
            appendChild( document.createElement( Xml::Content ) ).
            appendChild( document.createTextNode( lyrics_ ) );

    }

    return out;
}
