/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MenuBar.h"

#include "Application.h"
#include "CollectionWidget.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "MainWindow.h"
#include "PlaybackControlToolBar.h"
#include "PlaylistWidget.h"
#include "Singleton.h"

//__________________________________________________________________
MenuBar::MenuBar( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "MenuBar" )
{
    Debug::Throw( "MenuBar::MenuBar.\n" );

    auto application = Base::Singleton::get().application<Application>();
    auto mainWindow = static_cast<MainWindow*>( parentWidget() );

    auto menu = addMenu( tr( "File" ) );
    menu->addAction( &mainWindow->playbackControlToolBar().previousTrackAction() );
    menu->addAction( &mainWindow->playbackControlToolBar().startPlaybackAction() );
    menu->addAction( &mainWindow->playbackControlToolBar().stopPlaybackAction() );
    menu->addAction( &mainWindow->playbackControlToolBar().nextTrackAction() );
    menu->addSeparator();
    menu->addAction( &application->closeAction() );

    menu = addMenu( tr( "Tools" ) );
    menu->addAction( &mainWindow->playlistWidget().clearPlaylistAction() );
    menu->addAction( &mainWindow->playlistWidget().savePlaylistAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow->collapseAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow->showLogAction() );
    menu->addAction( &application->restartServerAction() );
    menu->addAction( &mainWindow->collectionWidget().updateCollectionAction() );
    menu->addAction( &mainWindow->downloadCoversAction() );

    menu = addMenu( tr( "Settings" ) );
    {
        auto subMenu = menu->addMenu( tr( "Playback mode" ) );
        auto actions( mainWindow->playbackControlToolBar().repeatModeActions() );
        for( auto&& action:actions )
        { subMenu->addAction( action ); }

        subMenu->addSeparator();
        subMenu->addAction( &mainWindow->playbackControlToolBar().randomPlaybackAction() );

    }

    menu->addSeparator();
    menu->addAction( &application->configurationAction() );

    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application->aboutAction() );
    menu->addAction( &application->aboutMpdAction() );
    menu->addAction( &application->aboutQtAction() );
    menu->addSeparator();
    auto debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );
}
