#ifndef MpdBaseSocket_h
#define MpdBaseSocket_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QObject>
namespace Mpd
{

    // forward declaration
    class ServerConfiguration;

    //* base class
    class BaseSocket: public QObject
    {

        Q_OBJECT

        public:

        //* factory
        static BaseSocket* create( QObject*, const ServerConfiguration& );
        static BaseSocket* create( const ServerConfiguration& configuration )
        { return create( nullptr, configuration ); }

        //*@name accessors
        //@{

        //* error string
        virtual QString errorString() const = 0;

        //* bytes available
        virtual qint64 bytesAvailable() const = 0;

        //* true if connected
        virtual bool isConnected() const = 0;

        //@}

        //*@name modifiers
        //@{

        //* connect to host defined by server configuration
        /** this is blocking */
        virtual bool connect( const ServerConfiguration& ) = 0;

        // disconnect
        /** this is blocking */
        virtual void disconnect() = 0;

        //* read
        virtual QByteArray read( qint64 ) = 0;

        //* read all
        virtual QByteArray readAll() = 0;

        //* write
        virtual qint64 write( const char* ) = 0;

        //* wait for ready read
        virtual bool waitForReadyRead() = 0;

        //* close
        virtual void close() = 0;

        //@}

        Q_SIGNALS:

        //* disconnected
        void disconnected();

        //* ready read
        void readyRead();

        //* error
        void error();

        protected:

        //* constructor
        explicit BaseSocket( QObject* parent ):
            QObject( parent )
            {}

    };

}

#endif
