#ifndef MpdController_h
#define MpdController_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "MpdServerConfiguration.h"

#include <QBasicTimer>
#include <QObject>
#include <QTimerEvent>

namespace Mpd
{
    class Controller: public QObject, private Base::Counter<Controller>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit Controller( QObject* = nullptr );

        //* destructor
        ~Controller() override;

        //*@name accessors
        //@{

        //* check server configuration
        bool checkServerConfiguration() const;

        //* true if server is running
        bool serverIsRunning() const;

        //* configuration
        const ServerConfiguration& serverConfiguration() const
        { return serverConfiguration_; }

        //@}

        //*@name modifiers
        //@{

        //* set server configuration
        void setServerConfiguration( const ServerConfiguration& value )
        { serverConfiguration_ = value; }

        //* start server
        bool startServer();

        //* stop server
        bool stopServer();

        //* wait for started
        /** warning, this method is blocking */
        bool waitForStarted( int msecs = 30000 );

        //* wait for stopped
        /** warning, this method is blocking */
        bool waitForStopped( int msecs = 30000 );

        //@}

        Q_SIGNALS:

        //* emitted when ready
        void serverReady();

        //* emitted when stopped
        void serverStopped();

        protected:

        //* timer event handler
        void timerEvent( QTimerEvent* ) override;

        private:

        //* server configuration
        ServerConfiguration serverConfiguration_;

        //* true when server is ready
        mutable bool serverReady_ = false;

        //* wait for started timer
        QBasicTimer serverStartedTimer_;

        //* wait for finished timer
        QBasicTimer serverStoppedTimer_;

    };

}

#endif
