#ifndef MpdIdleInterface_h
#define MpdIdleInterface_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "MpdCommand.h"
#include "MpdServerConfiguration.h"
#include "ObjectDeleter.h"

#include <QObject>
#include <QByteArray>

#include <memory>

namespace Mpd
{

    class BaseSocket;

    class IdleInterface: public QObject, private Base::Counter<IdleInterface>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit IdleInterface( QObject* = nullptr );

        //* destructor
        ~IdleInterface() override;

        //*@name modifiers
        //@{

        //* server configuratio
        void setServerConfiguration( const ServerConfiguration& value )
        { serverConfiguration_ = value; }

        //@}

        using QObject::connect;

        Q_SIGNALS:

        //* request status update
        void requestUpdateStatus();

        //* playlist update
        void requestUpdatePlaylist();

        //* collection update
        void requestLoadCollection();

        //* request load stored playlists
        void requestLoadStoredPlaylists();

        //* socket error
        void socketError();

        public Q_SLOTS:

        //* connect
        void connectSocket();

        //* disconnect
        void disconnectSocket();

        private Q_SLOTS:

        //* read from socket
        void _readFromSocket();

        //* disconnected
        void _socketDisconnected();

        private:

        //* check if socket is connected
        bool _isSocketConnected() const;

        //* command
        void _processReply( const QString& );

        //* server configuration
        ServerConfiguration serverConfiguration_;

        //* socket
        std::unique_ptr<BaseSocket, Base::ObjectDeleter> socket_;

        //* buffer
        QString buffer_;

    };

}

#endif
