#ifndef MpdInterface_h
#define MpdInterface_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "MpdCommand.h"
#include "MpdServerConfiguration.h"
#include "ObjectDeleter.h"

#include <QObject>
#include <QByteArray>

#include <memory>

namespace Mpd
{

    class BaseSocket;

    class Interface: public QObject, private Base::Counter<Interface>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit Interface( QObject* = nullptr );

        //* destructor
        ~Interface() override;

        //*@name accessors
        //@{

        //* mpd version
        QString version() const
        { return version_; }

        //* server configuration
        ServerConfiguration serverConfiguration() const
        { return serverConfiguration_; }

        //@}

        //*@name modifiers
        //@{

        //* server configuration
        void setServerConfiguration( const ServerConfiguration& value )
        { serverConfiguration_ = value; }

        //@}

        Q_SIGNALS:

        //* mpd version available
        void versionAvailable( QString );

        //* command completed
        void commandCompleted( Mpd::Command );

        //* command completed
        void commandFailed( Mpd::Command );

        //* socket error
        void socketError();

        public Q_SLOTS:

        //* add command
        bool addCommand( Mpd::Command );

        //* add command
        bool addCommands( Mpd::Command::List );

        //* connect
        bool connectSocket();

        //* disconnect
        void disconnectSocket();

        private Q_SLOTS:

        //* disconnected
        void _socketDisconnected();

        private:

        //* check if socket is connected
        bool _isSocketConnected() const;

        //* send command
        void _sendCommand( QString );

        //* read from socket
        QString _readFromSocket();

        //* server configuration
        ServerConfiguration serverConfiguration_;

        //* socket
        std::unique_ptr<BaseSocket, Base::ObjectDeleter> socket_;

        //* mpd versions
        QString version_;

    };

}

#endif
