/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MpdStatus.h"
#include "CppUtil.h"
#include "Debug.h"

#include <QRegExp>
#include <QStringList>

namespace Mpd
{

    //_______________________________________________
    Status::Status( const QString& reply ):
        Counter( "Mpd::Status" )
    {

        Debug::Throw( "Mpd::Status::Status.\n" );
        auto parse = []( const QString& input, const QString& key )
        { return input.startsWith(key) ? std::make_pair( true, input.mid( key.length() ) ) : std::make_pair( false, QString() ); };

        const auto replyList( reply.split( '\n', QString::SkipEmptyParts ) );
        std::pair<bool, QString> result;

        bool repeat = false;
        bool single = false;

        for( const auto& replyString:replyList )
        {

            if( ( result = parse( replyString, "volume: " ) ).first ) volume_ = result.second.toInt();
            else if( ( result = parse( replyString, "repeat: " ) ).first ) repeat = static_cast<bool>( result.second.toInt() );
            else if( ( result = parse( replyString, "single: " ) ).first ) single = static_cast<bool>( result.second.toInt() );
            else if( ( result = parse( replyString, "random: " ) ).first ) random_ = static_cast<bool>( result.second.toInt() );
            else if( ( result = parse( replyString, "consume: " ) ).first ) consume_ = static_cast<bool>( result.second.toInt() );
            else if( ( result = parse( replyString, "playlist: " ) ).first ) playlistId_ = result.second.toUInt();
            else if( ( result = parse( replyString, "playlistlength: " ) ).first ) playlistLength_ = result.second.toUInt();
            else if( ( result = parse( replyString, "state: " ) ).first )
            {
                if( result.second.startsWith( "play" ) ) state_ = State::Playing;
                else if( result.second.startsWith( "stop" ) ) state_ = State::Stopped;
                else if( result.second.startsWith( "pause" ) ) state_ = State::Paused;

                Debug::Throw() << "Mpd::Status::Status - state: " << Base::toIntegralType( state_ ) << endl;
            }
            else if( ( result = parse( replyString, "song: " ) ).first ) currentTrackIndex_ = result.second.toUInt();
            else if( ( result = parse( replyString, "songid: " ) ).first ) currentTrackId_ = result.second.toUInt();
            else if( ( result = parse( replyString, "time: " ) ).first )
            {
                const auto position( result.second.indexOf( ':' ) );
                elapsedTime_ = result.second.left( position ).toUInt();
                totalTime_ = result.second.mid( position+1 ).toUInt();
            }
            else if( ( result = parse( replyString, "updating_db: " ) ).first ) updateJobId_ = result.second.toInt();
            else if( ( result = parse( replyString, "error: " ) ).first ) error_ = result.second;
        }

        // assign repeat mode
        if( repeat ) repeatMode_ = single ? RepeatMode::RepeatOne : RepeatMode::RepeatAll;
        else repeatMode_ = RepeatMode::RepeatNone;

    }

}
