#ifndef MpdStatus_h
#define MpdStatus_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "MpdDefines.h"

#include <QString>

namespace Mpd
{

    class Status: private Base::Counter<Status>
    {

        public:

        //* default constructor
        explicit Status(): Counter( "Mpd::Status" )
        {}

        //* constructor from command reply
        explicit Status( const QString& );

        //*@name accessors
        //@{

        int volume() const
        { return volume_; }

        RepeatMode repeatMode() const
        { return repeatMode_; }

        bool random() const
        { return random_; }

        bool consume() const
        { return consume_; }

        qint32 playlistId() const
        { return playlistId_; }

        qint32 playlistLength() const
        { return playlistLength_; }

        State state() const
        { return state_; }

        qint32 currentTrackIndex() const
        { return currentTrackIndex_; }

        qint32 currentTrackId() const
        { return currentTrackId_; }

        quint32 elapsedTime() const
        { return elapsedTime_; }

        quint32 totalTime() const
        { return totalTime_; }

        qint32 updateJobId() const
        { return updateJobId_; }

        QString error() const
        { return error_; }

        //@}


        private:

        //* volume
        int volume_ = 0;

        //* repeat mode
        RepeatMode repeatMode_ = RepeatMode::RepeatNone;

        //* random playback
        bool random_ = false;

        //* consume playback (not implemented)
        bool consume_ = false;

        //* playlist id
        qint32 playlistId_ = -1;

        //* number of tracks in playlist
        qint32 playlistLength_ = 0;

        //* playback state
        State state_ = State::Stopped;

        //* index of the current track (position in playlist)
        qint32 currentTrackIndex_ = -1;

        //* id of the current track
        qint32 currentTrackId_ = -1;

        //* ellapsed time for the current track
        quint32 elapsedTime_ = 0;

        //* total time for the current track
        quint32 totalTime_ = 0;

        //* id of an ongoing update job
        qint32 updateJobId_ = -1;

        //* mpd error
        QString error_;
    };

}

#endif
