#ifndef NetworkJob_h
#define NetworkJob_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ObjectDeleter.h"

#include <QNetworkReply>
#include <QObject>

#include <memory>

//* generic network job
class NetworkJob: public QObject, private Base::Counter<NetworkJob>
{

    Q_OBJECT

    public:

    //* constructor
    explicit NetworkJob( QNetworkReply* );

    //* destructor
    ~NetworkJob() override;

    Q_SIGNALS:

    //* finished
    void finished();

    protected Q_SLOTS:

    //* finished
    virtual void _finished() = 0;

    protected:

    //* true if network reply is valid
    bool _hasNetworkReply() const
    { return static_cast<bool>(networkReply_); }

    //* accessor
    QNetworkReply& _networkReply() const
    { return *networkReply_; }

    // make sure finished signal is sent when exiting this method
    class SignalEmiter
    {
        public:

        //*constructor
        explicit SignalEmiter( NetworkJob* job ):
            job_( job )
            {}

        //* destructor
        ~SignalEmiter()
        { emit job_->finished(); }

        private:

        //* job
        NetworkJob* job_;

    };

    private Q_SLOTS:

    //* abort job
    void _abort();

    private:

    //* network reply
    std::unique_ptr<QNetworkReply, Base::ObjectDeleter> networkReply_;

};


#endif
