/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "NewAudioStreamDialog.h"

#include "Debug.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "LineEditor.h"
#include "TimeStamp.h"

#include <QLabel>
#include <QUrl>

//____________________________________________________________
NewAudioStreamDialog::NewAudioStreamDialog( QWidget* parent ):
    CustomDialog( parent, OkButton|CancelButton )
{
    Debug::Throw( "NewAudioStreamDialog::NewAudioStreamDialog.\n" );
    setWindowTitle( tr( "Add Stream" ) );
    setOptionName( "NEW_STREAM_DIALOG" );

    auto gridLayout = new GridLayout;
    gridLayout->setMargin(0);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignCenter );

    mainLayout().addLayout( gridLayout );
    QLabel* label;
    gridLayout->addWidget( label = new QLabel( tr( "URL:" ) ) );
    gridLayout->addWidget( urlEditor_ = new LineEditor( this ) );
    label->setBuddy( urlEditor_ );

    gridLayout->addWidget( label = new QLabel( tr( "Name:" ) ) );
    gridLayout->addWidget( nameEditor_ = new LineEditor( this ) );
    label->setBuddy( nameEditor_ );

    connect( urlEditor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons()) );
    connect( nameEditor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons()) );

    urlEditor_->setFocus();

    okButton().setText( tr( "Add" ) );
    okButton().setIcon( IconEngine::get( IconNames::Add ) );
    okButton().setEnabled( false );
}

//____________________________________________________________
QString NewAudioStreamDialog::url() const
{ return urlEditor_->text().trimmed(); }

//____________________________________________________________
QString NewAudioStreamDialog::name() const
{ return nameEditor_->text(); }

//____________________________________________________________
void NewAudioStreamDialog::_updateButtons()
{

    Debug::Throw("NewAudioStreamDialog::_updateButtons.\n" );

    if( name().isEmpty() ) { okButton().setEnabled( false ); return; }

    const auto url( this->url() );
    if( url.isEmpty() ) { okButton().setEnabled( false ); return; }

    // check if valid
    if( !url.contains( "://" ) ) { okButton().setEnabled( false ); return; }

    // check protocol
    if( !( urlHandlers_.isEmpty() || urlHandlers_.contains( QUrl( url ).scheme() ) ) ) { okButton().setEnabled( false ); return; }

    // enable
    okButton().setEnabled( true );

}
