#ifndef PlaylistWriter_h
#define PlaylistWriter_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "TrackInformation.h"

#include <QByteArray>

class PlaylistWriter: private Base::Counter<PlaylistWriter>
{

    public:

    enum class Format
    {
        M3u,
        Xspf
    };

    //* guess format from filename
    static Format playlistFormat( const File& );

    //* default extension for given format
    static QString formatExtension( Format );

    //* default format
    static Format defaultFormat();

    //* default extension
    static QString defaultExtension()
    { return formatExtension( defaultFormat() ); }

    //* constructor
    explicit PlaylistWriter();

    //*@name accessor
    //@{

    template<class T>
    QByteArray create( const QList<T>&, Format = Format::Xspf ) const;

    //@}

    //*@name use absolute filenames
    //@{

    void setUseAbsolutePath( bool value )
    { useAbsolutePath_ = value; }

    //@}

    private:

    //* create m3u files
    QByteArray _createM3u( const TrackInformation::List& ) const;

    //* create xspf
    QByteArray _createXspf( const TrackInformation::List& ) const;

    //* true for using absolute path
    bool useAbsolutePath_ = true;

};

template<class T>
QByteArray PlaylistWriter::create( const QList<T>& items, Format format ) const
{
    TrackInformation::List tracks;
    std::copy( items.begin(), items.end(), std::back_inserter( tracks ) );
    return create<TrackInformation>( tracks, format );
}

//* track information specialization
template<>
QByteArray PlaylistWriter::create( const QList<TrackInformation>&, Format ) const;

#endif
