/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SavePlaylistDialog.h"

#include "Debug.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "LineEditor.h"
#include "TimeStamp.h"

#include <QLabel>

//____________________________________________________________
SavePlaylistDialog::SavePlaylistDialog( QWidget* parent ):
    CustomDialog( parent, OkButton|CancelButton )
{
    Debug::Throw( "SavePlaylistDialog::SavePlaylistDialog.\n" );
    setWindowTitle( tr( "Save Playlist" ) );
    setOptionName( "SAVE_PLAYLIST_DIALOG" );

    QLabel* label;
    mainLayout().addWidget( label = new QLabel( tr( "Playlist name:" ), this ) );
    mainLayout().addWidget( editor_ = new LineEditor( this ) );
    connect( editor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons()) );
    label->setBuddy( editor_ );

    editor_->setFocus();

    okButton().setText( tr( "Save" ) );
    okButton().setIcon( IconEngine::get( IconNames::Save ) );
    okButton().setEnabled( false );
}

//____________________________________________________________
QString SavePlaylistDialog::playlist() const
{
    auto name = editor_->text();
    if( name.isEmpty() ) return name;
    else return QString( "%1_{%2}" ).arg(name).arg( TimeStamp::now().unixTime() );
}

//____________________________________________________________
void SavePlaylistDialog::setPlaylist( const QString& value )
{ editor_->setText( value ); }

//____________________________________________________________
void SavePlaylistDialog::_updateButtons()
{ okButton().setEnabled( !editor_->text().isEmpty() ); }
