/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "SidePanelOptionWidget.h"

#include "CppUtil.h"
#include "XmlOptions.h"

#include <QLayout>

//_________________________________________________________________
SidePanelOptionWidget::SidePanelOptionWidget( QWidget* parent ):
    QWidget( parent ),
    OptionWidget( "SIDE_PANEL_MASK", this )
{

    setWindowTitle( tr( "Logbook Entry Configuration" ) );

    auto layout = new QVBoxLayout;
    setLayout( layout );

    // insert checkboxes
    checkBoxes_ = Base::makeT<CheckBoxList>(
    {
       new QCheckBox( tr( "Collection" ), this ),
       new QCheckBox( tr( "Stored playlists" ), this ),
       new QCheckBox( tr( "Lyrics" ), this ),
       new QCheckBox( tr( "File system" ), this ),
       new QCheckBox( tr( "Audio streams" ), this ),
       new QCheckBox( tr( "Audio device" ), this )
    } );

    // insert in layout
    for( auto&& checkbox:checkBoxes_ )
    {
        connect( checkbox, SIGNAL(toggled(bool)), SLOT(_updateMask()) );
        layout->addWidget( checkbox );
    }

    layout->addStretch(1);

}

//_________________________________________________________________
void SidePanelOptionWidget::read( const Options& options )
{

    const unsigned int mask( options.get<unsigned int>( optionName() ) );
    for( int i = 0; i < checkBoxes_.size(); ++i )
    { checkBoxes_[i]->setChecked( mask&(1<<i) ); }

    _setConnected();
}

//_________________________________________________________________
void SidePanelOptionWidget::write( Options& options ) const
{
    unsigned int value = 0;
    for( int i = 0; i < checkBoxes_.size(); ++i )
    { if( checkBoxes_[i]->isChecked() ) value |= (1<<i); }

    options.set<unsigned int>( optionName(), value );
}
