#ifndef SidePanelWidget_h
#define SidePanelWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "File.h"

#include <QAction>
#include <QShowEvent>
#include <QStackedWidget>
#include <QToolButton>

class BaseStatusBar;
class CollectionWidget;
class FileSystemWidget;
class LyricsWidget;
class AudioStreamWidget;
class StoredPlaylistWidget;

#if WITH_CDIO_PARANOIA
class AudioDeviceWidget;
#endif

//* editor windows navigator
class SidePanelWidget: public QWidget
{

    Q_OBJECT

    public:

    //* creator
    explicit SidePanelWidget( QWidget* = nullptr  );

    //*@name accessors
    //@{

    //* size
    QSize sizeHint() const override
    {
        return (defaultWidth_ ) >= 0 ?
            QSize( defaultWidth_, 0 ):
            QWidget::sizeHint();
    }

    //* collection
    CollectionWidget& collectionWidget() const
    { return *collectionWidget_; }

    //* stored playlists
    StoredPlaylistWidget& storedPlaylistWidget() const
    { return *storedPlaylistWidget_; }

    //* lyrics
    LyricsWidget& lyricsWidget() const
    { return *lyricsWidget_; }

    //* file system
    FileSystemWidget& fileSystemWidget() const
    { return *fileSystemWidget_; }

    //* podecasts
    AudioStreamWidget& audioStreamWidget() const
    { return *audioStreamWidget_; }

    #if WITH_CDIO_PARANOIA
    //* audio device
    AudioDeviceWidget& audioDeviceWidget() const
    { return *audioDeviceWidget_; }
    #endif

    //* current widget
    QWidget* currentWidget() const
    { return stackedWidget_->currentWidget(); }

    //* visibility
    QAction& visibilityAction() const
    { return *visibilityAction_; }

    //* statusbar
    BaseStatusBar& statusBar() const
    { return *statusBar_; }

    //@}

    //*@name modifiers
    //@{

    //* default size
    void setDefaultWidth( int value )
    { defaultWidth_ = value; }

    //* current widget
    void setCurrentWidget( QWidget* widget )
    { stackedWidget_->setCurrentWidget( widget ); }

    //@}

    Q_SIGNALS:

    void currentChanged( int );

    private Q_SLOTS:

    //* update current widget
    void _updateCurrentWidget();

    //* update configuration
    void _updateConfiguration();

    //* update current path
    void _saveConfiguration();

    private:

    //* install actions
    void _installActions();

    //* default width;
    int defaultWidth_ = -1;

    //* stack widget
    QStackedWidget* stackedWidget_ = nullptr;

    //* collection
    CollectionWidget* collectionWidget_ = nullptr;

    //* stored playlists
    StoredPlaylistWidget* storedPlaylistWidget_ = nullptr;

    //* lyrics
    LyricsWidget* lyricsWidget_ = nullptr;

    //* file system
    FileSystemWidget* fileSystemWidget_ = nullptr;

    //* audioStream
    AudioStreamWidget* audioStreamWidget_ = nullptr;

    #if WITH_CDIO_PARANOIA
    //* audio device
    AudioDeviceWidget* audioDeviceWidget_ = nullptr;
    #endif

    //* status bar
    BaseStatusBar* statusBar_ = nullptr;

    //* visibility action
    QAction* visibilityAction_ = nullptr;

};

#endif
