/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "StoredPlaylistItemToolTipWidget.h"

#include "CustomPixmap.h"
#include "GridLayoutItem.h"
#include "Operators.h"

//_______________________________________________________
void StoredPlaylistItemToolTipWidget::setStoredPlaylistItem( const StoredPlaylistItem& item, const QIcon& icon )
{
    Debug::Throw( "StoredPlaylistItemToolTipWidget::setRecord.\n" );

    // local storage
    _setIcon( icon );
    item_ = item;

    // update icon
    if( !icon.isNull() )
    {

        // get pixmap
        _iconLabel().setPixmap( icon.pixmap( QSize( _pixmapSize(), _pixmapSize() ) ) );
        _iconLabel().show();

    } else _iconLabel().hide();

    // artist
    if( item.type() == StoredPlaylistItem::Type::Playlist )
    {

        _artistItem().setKey( tr( "Name:" ) );
        _artistItem().setText( item.displayName() );

    } else {

        _artistItem().setKey( tr( "Artist:" ) );
        _artistItem().setText( item.artist().isEmpty() ? TrackInformation::UnknownArtist:item.artist() );

    }

    // album or creation
    if( item.type() == StoredPlaylistItem::Type::Playlist && item.creation().isValid() )
    {

        _albumItem().setKey( tr( "Created:" ) );
        _albumItem().setText( item.creation().toString() );

    } else if( item.type() == StoredPlaylistItem::Type::Track ) {

        _albumItem().setKey( tr( "Album:" ) );
        _albumItem().setText( item.album().isEmpty() ? TrackInformation::UnknownAlbum:item.album() );

    } else _albumItem().hide();

    // title or modification
    if( item.type() == StoredPlaylistItem::Type::Playlist && item.modification().isValid() && item.modification() != item.creation() )
    {

        _titleItem().setKey( tr( "Modified:" ) );
        _titleItem().setText( item.modification().toString() );

    } else if( item.type() == StoredPlaylistItem::Type::Track ) {

        _titleItem().setKey( tr( "Title:" ) );
        _titleItem().setText( item.titleOrFile() );

    } else _titleItem().hide();

    // year
    if( item.year() > 0 && item.type() == StoredPlaylistItem::Type::Track )
    {

        _yearItem().setText( QString::number( item.year() ) );

    } else _yearItem().hide();

    // track
    if( item.type() == StoredPlaylistItem::Type::Playlist && item.trackCount() > 0 ) {

        _trackItem().setKey( tr( "Tracks:" ) );
        _trackItem().setText( QString::number( item.trackCount() ) );

    } else _trackItem().hide();

    // track
    if( item.disc() > 0 && item.type() == StoredPlaylistItem::Type::Track  )
    {

        _discItem().setText( QString::number( item.disc() ) );

    } else _discItem().hide();

    // duration
    if( item.duration() > 0 )
    {

        _durationItem().setText( item.durationString( item.type() == StoredPlaylistItem::Type::Playlist ) );

    } else _durationItem().hide();

    adjustSize();

}

//_____________________________________________
bool StoredPlaylistItemToolTipWidget::_updateCover( const CollectionItem& item, const QImage& image )
{
    if( isVisible() && item_.artist() == item.artist() && item_.album() == item.album() && !image.isNull() )
    {

        _setIcon( QIcon( QPixmap::fromImage( image ) ) );
        _reload();
        return true;

    } else return false;

}
