#ifndef TagEditionDialog_h
#define TagEditionDialog_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"

#include "AlbumInformationManager.h"
#include "File.h"
#include "TrackInformation.h"

#include <QLabel>
#include <QSpinBox>
#include <QToolButton>

class CustomComboBox;
class LineEditor;

class TagEditionDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //* constructor
    explicit TagEditionDialog( QWidget* = nullptr );

    //*@name accessors
    //@{

    //* location
    File location() const;

    //@}

    //*@name modifiers
    //@{

    //* reset files and editors
    void reset();

    //* set files
    bool setFiles( const File::List& );

    //* add files
    void addFiles( const File::List& );

    //* read saved files
    bool readFiles();

    //* artists
    void setArtists( const QStringList& );

    //* albums
    void setAlbums( const QStringList& );

    //@}

    Q_SIGNALS:

    //* album information
    void requestAlbumInformation( TrackInformation );

    public Q_SLOTS:

    //* set release date
    void updateYear( AlbumInformationManager::ReleaseDateList );

    private Q_SLOTS:

    //* update buttons
    void _updateButtons();

    //* request album information
    void _requestAlbumInformation();

    //* save tags
    void _saveTags();

    private:

    //* true if modified
    bool _modified() const;

    //* update editors from backup
    void _updateEditors();

    //* files
    File::List files_;

    //* writable files
    bool hasWritableFiles_ = false;

    //* original track information
    TrackInformation backup_;

    //* location
    LineEditor* locationEditor_ = nullptr;

    //* artist
    CustomComboBox* artistEditor_ = nullptr;

    //* album
    CustomComboBox* albumEditor_ = nullptr;

    //* title
    LineEditor* titleEditor_ = nullptr;

    //* year
    QSpinBox* yearEditor_ = nullptr;

    //* year
    QToolButton* updateYearButton_ = nullptr;

    //* disc
    QSpinBox* discNumberEditor_ = nullptr;

    //* track number
    QSpinBox* trackNumberEditor_ = nullptr;

    //* label to warn if no file is writable
    QLabel* readOnlyLabel_ = nullptr;

};

#endif
