/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TrackInformationModel.h"

#include "CollectionItem.h"
#include "CppUtil.h"
#include "IconEngine.h"
#include "IconNames.h"

#include <QMimeData>
#include <QUrl>

//_______________________________________________________________________________________
TrackInformationModel::TrackInformationModel( QObject* parent ):
    ListModel( parent ),
    Counter( "TrackInformationModel" )
{}

//_______________________________________________________________________________________
Qt::ItemFlags TrackInformationModel::flags( const QModelIndex& index ) const
{ return index.isValid() ? Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled: Qt::NoItemFlags; }

//_______________________________________________________________________________________
QVariant TrackInformationModel::data( const QModelIndex& index, int role ) const
{

    // check index
    if( !contains( index ) ) return QVariant();

    // return text associated to file and column
    if( role == Qt::DisplayRole )
    {
        const auto& track( get(index) );
        return track.artist() + " " + track.album() + " " + track.titleOrFile();
    }

    return QVariant();

}

//__________________________________________________________________
QIcon TrackInformationModel::icon( const TrackInformation& trackInformation ) const
{
    if( trackInformation.isAudioStream() )
    {

        return cache_ ?
            cache_->icon( CollectionItem( trackInformation ) ):
            QIcon();

    } else {

        return cache_ ?
            cache_->icon( CollectionItem( CollectionItem::Type::Album, trackInformation.artist(), trackInformation.album() ) ):
            QIcon();

    }

}

//__________________________________________________________________
void TrackInformationModel::setCoverCache( const CoverCache::Pointer& value )
{
    cache_ = value;
    connect( cache_.get(), SIGNAL(modified()), SIGNAL(layoutAboutToBeChanged()) );
    connect( cache_.get(), SIGNAL(modified()), SIGNAL(layoutChanged()) );
}
