/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TrackInformationToolTipWidget.h"

#include "CustomPixmap.h"
#include "GridLayoutItem.h"

//_______________________________________________________
TrackInformationToolTipWidget::TrackInformationToolTipWidget( QWidget* parent ):
    ToolTipWidget( parent )
{ _trackItem().hide(); }

//_______________________________________________________
void TrackInformationToolTipWidget::setTrackInformation( const TrackInformation& trackInformation, const QIcon& icon )
{
    Debug::Throw( "TrackInformationToolTipWidget::setRecord.\n" );

    // local storage
    _setIcon( icon );
    trackInformation_ = trackInformation;

    // update icon
    if( !icon.isNull() )
    {

        // get pixmap
        _iconLabel().setPixmap( icon.pixmap( QSize( _pixmapSize(), _pixmapSize() ) ) );
        _iconLabel().show();

    } else _iconLabel().hide();

    // channel
    if( !trackInformation.channel().isEmpty() )
    {

        _channelItem().setText( trackInformation.channel() );
        _channelItem().show();

    } else _channelItem().hide();

    // artist
    if( !trackInformation.artist().isEmpty() )
    {

        _artistItem().setText( trackInformation.artist() );
        _artistItem().show();

    } else _artistItem().hide();

    // album
    if( !trackInformation.album().isEmpty() )
    {

        _albumItem().setText( trackInformation.album() );
        _albumItem().show();

    } else _albumItem().hide();

    // title
    _titleItem().setText( trackInformation.titleOrFile() );

    // year
    if( trackInformation.year() > 0 )
    {

        _yearItem().setText( QString::number( trackInformation.year() ) );

    } else _yearItem().hide();

    // disk
    if( trackInformation.disc() > 0 )
    {

        _discItem().setText( QString::number( trackInformation.disc() ) );

    } else _discItem().hide();

    // duration
    if( trackInformation.duration() > 0 )
    {

        _durationItem().setText( trackInformation.durationString() );

    } else _durationItem().hide();

    adjustSize();

}

//_____________________________________________
bool TrackInformationToolTipWidget::_updateCover( const CollectionItem& item, const QImage& image )
{
    Debug::Throw( "TrackInformationToolTipWidget::_updateCover.\n" );
    if( isVisible() && trackInformation_.artist() == item.artist() && trackInformation_.album() == item.album() && !image.isNull() )
    {

        _setIcon( QIcon( QPixmap::fromImage( image ) ) );
        _reload();
        return true;

    } else return false;

}

