/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "CommandLineArguments.h"
#include "Debug.h"
#include "DefaultOptions.h"
#include "FileSystemDefaultOptions.h"
#include "InterruptionHandler.h"
#include "MpdInterface.h"
#include "Singleton.h"
#include "SvgDefaultOptions.h"
#include "SystemOptions.h"

#include "XmlOptions.h"

#include <QApplication>
#include <unistd.h>

#if defined(QT_USE_STATIC_PLUGINS)
#include <QtPlugin>
Q_IMPORT_PLUGIN(qsvg)
#endif

//__________________________________________
//* custom interruption handler
void handleInterruption( int signal )
{
    #if !defined(Q_OS_WIN)
    Debug::Throw(0) << "handleInterruption - recieved " << strsignal( signal ) << " (" << signal << ")" << endl;
    #endif

    auto application( Base::Singleton::get().application<Application>() );
    if( application ) application->closeAction().trigger();
    else qApp->quit();
}

//__________________________________________
//* main function
int main (int argc, char *argv[])
{

    // options
    installDefaultOptions();
    installSystemOptions();
    installSvgOptions();
    installFileSystemOptions();

    // modify interruption handler
    InterruptionHandler::get().setInterruptionHandlerFunction( handleInterruption );

    File rcFile( XmlOptions::get().raw( "RC_FILE" ) );
    XmlOptions::setFile( rcFile );
    XmlOptions::read();

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // resources
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( lyricsProviderList );

    // QApplication
    QApplication application( argc, argv );

    Application singleton( CommandLineArguments( argc, argv ) );
    Base::Singleton::get().setApplication( &singleton );

    // initialize and run
    if( singleton.initApplicationManager() )
    { application.exec(); }

    return 0;
}
